require 'rbconfig'
require 'shellwords'

module Libv8; end

module Libv8::Node
  module Paths
    module_function

    def include_paths
      [Shellwords.escape(File.join(vendored_source_path, 'include')),
       Shellwords.escape(File.join(RbConfig::MAKEFILE_CONFIG["includedir"])),
       Shellwords.escape(RbConfig::CONFIG["includedir"])]
    end

    def object_paths
      [Shellwords.escape(File.join(vendored_source_path, 'out.gn', 'libv8', 'obj')),
       Shellwords.escape(RbConfig::CONFIG["libdir"])]
    end

    def platform
      Gem::Platform.local.tap { |p| RUBY_PLATFORM =~ /musl/ && p.version.nil? && p.instance_eval { @version = 'musl' } }.to_s.gsub(/-darwin-?\d+/, '-darwin')
    end

    def config
      RbConfig::MAKEFILE_CONFIG
    end

    def vendored_source_path
      File.expand_path('../../vendor/v8', __dir__)
    end
  end
end
